==> kubernetes-model-batch-5.11.0-sources.jar: io/fabric8/kubernetes/api/model/batch/v1beta1/CronJobListBuilder.java <==
package io.fabric8.kubernetes.api.model.batch.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CronJobListBuilder extends io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobListFluentImpl<io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobList,io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobListBuilder>{
  public CronJobListBuilder() {
    this(false);
  }
  public CronJobListBuilder(java.lang.Boolean validationEnabled) {
    this(new CronJobList(), validationEnabled);
  }
  public CronJobListBuilder(io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobListFluent<?> fluent) {
    this(fluent, false);
  }
  public CronJobListBuilder(io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CronJobList(), validationEnabled);
  }
  public CronJobListBuilder(io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobListFluent<?> fluent,io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobList instance) {
    this(fluent, instance, false);
  }
  public CronJobListBuilder(io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobListFluent<?> fluent,io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public CronJobListBuilder(io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobList instance) {
    this(instance,false);
  }
  public CronJobListBuilder(io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobList build() {
    CronJobList buildable = new CronJobList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CronJobListBuilder that = (CronJobListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-batch-6.2.0-sources.jar: io/fabric8/kubernetes/api/model/batch/v1beta1/CronJobListBuilder.java <==
package io.fabric8.kubernetes.api.model.batch.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class CronJobListBuilder extends CronJobListFluentImpl<CronJobListBuilder> implements VisitableBuilder<CronJobList,CronJobListBuilder>{
  public CronJobListBuilder() {
    this(false);
  }
  public CronJobListBuilder(Boolean validationEnabled) {
    this(new CronJobList(), validationEnabled);
  }
  public CronJobListBuilder(CronJobListFluent<?> fluent) {
    this(fluent, false);
  }
  public CronJobListBuilder(CronJobListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new CronJobList(), validationEnabled);
  }
  public CronJobListBuilder(CronJobListFluent<?> fluent,CronJobList instance) {
    this(fluent, instance, false);
  }
  public CronJobListBuilder(CronJobListFluent<?> fluent,CronJobList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public CronJobListBuilder(CronJobList instance) {
    this(instance,false);
  }
  public CronJobListBuilder(CronJobList instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  CronJobListFluent<?> fluent;
  Boolean validationEnabled;
  public CronJobList build() {
    CronJobList buildable = new CronJobList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
